.. _network-module:

===========
chi.network
===========

The :mod:`chi.network` module exposes a functional interface for interacting
with the various networking capabilities of the testbed.

.. automodule:: chi.network
   :members:

Wizards
=======

There are additionally some functions that tie together several common tasks.

.. autoclass:: chi.network.wizard
   :members:
